import 'dart:io';
import 'dart:math';
import 'dart:typed_data';
import 'package:firebase_storage/firebase_storage.dart';
import 'package:image_picker/image_picker.dart';
import 'package:path_provider/path_provider.dart';
import 'package:http/http.dart' as http;

class StorageService {
  Future<File> getFileFromUrl(String url) async {
    Directory tempDir = await getTemporaryDirectory();
    var filePath = tempDir.path + '${Random().nextInt(1000000)}' + '.mp4';
    var response = await http.get(Uri.parse(url));
    return File(filePath).writeAsBytes(response.bodyBytes);
  }

  Reference _getRef(String extension) {
    final int random = Random().nextInt(1000000);

    final filePath = 'videos/$random.$extension';

    final Reference reference = FirebaseStorage.instance.ref().child(filePath);

    return reference;
  }

  Future<String> getVideoUrlFromXFile(XFile file, String extension) async {
    final data = await file.readAsBytes();

    final TaskSnapshot taskSnapshot = await _getRef(extension).putData(
        data,
        // MIME types
        SettableMetadata(
          contentType: "video/$extension",
        )
    );

    final String downloadUrl = await taskSnapshot.ref.getDownloadURL();

    return downloadUrl;
  }

  Future<String> getImageUrlFromXFile(XFile file) async {
    final Uint8List data = await file.readAsBytes();

    final int random = Random().nextInt(1000000);

    final filePath = 'images/$random.png';

    final Reference reference = FirebaseStorage.instance.ref().child(filePath);

    final TaskSnapshot taskSnapshot = await reference.putData(
        data,
        // MIME types
        SettableMetadata(
          contentType: "image/png",
        )
    );

    final String downloadUrl = await taskSnapshot.ref.getDownloadURL();

    return downloadUrl;
  }
}