import 'package:firebase_auth/firebase_auth.dart';
import 'package:flutter/material.dart';
import 'package:flutter_helper/src/View/text_field_view.dart';
import 'package:flutter_helper/src/service/auth_service.dart';
import 'package:flutter_helper/src/util/view_util.dart';

class AuthUtil {
  void onLinkSent(BuildContext context) {
    Navigator.of(context).pop();

    showDialogView(
      context,
      builder: (context) => AlertDialog(
        title: Text('All done!'),
        content:
        Text("A password reset link has been sent to your email address"),
        actions: <Widget>[
          TextButton(
            child: Text('OK'),
            onPressed: () {
              Navigator.of(context).pop();
            },
          )
        ],
      ),
    );
  }

  final TextEditingController _resetController = TextEditingController();

  void onForgotPassword(BuildContext context, {Key? key}) {
    final GlobalKey<FormState> _formKey = GlobalKey<FormState>();

    showDialogView(
        context,
        builder: (context) => AlertDialog(
          title: Text('Forgot your password?'),
          content: Column(
            mainAxisSize: MainAxisSize.min,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(
                  'If an account exists, we will send details on how to set a new password.'),
              Form(
                key: _formKey,
                child: Padding(
                  padding: const EdgeInsets.only(top: 20.0),
                  child: TextFieldView(
                      label: "Enter your email", controller: _resetController),
                ),
              )
            ],
          ),
          actions: <Widget>[
            TextButton(
              child: Text("DISMISS"),
              onPressed: () {
                Navigator.of(context).pop();
              },
            ),
            TextButton(
              child: Text("SEND"),
              onPressed: () async {
                try {
                  await AuthService().resetPassword(_resetController.text);

                  showOnAuthSuccessDialog(context);
                } on FirebaseAuthException catch (error) {
                  showOnAuthErrorDialog(context, error, key: key);
                }
              },
            )
          ],
        )
    );
  }

  Future<void> showOnAuthSuccessDialog(BuildContext context) async {
    showDialogView(
      context,
      builder: (context) => AlertDialog(
        title: Text("Sent"),
        content: Text("instructions to change your password have been sent. If you don't get it in a few minutes, please check your spam folder"),
        actions: <Widget>[
          TextButton(
            child: Text('OK'),
            onPressed: () {
              Navigator.of(context).pop();
            },
          )
        ],
      ),
    );
  }

  Future<void> showOnAuthErrorDialog(BuildContext context, FirebaseAuthException error, {Key? key}) async {
    String message = error.message ?? "";

    String title = "";

    // Sign up errors
    if (error.code == "email-already-in-use") {
      message = "The email address is already in use by another account.";

      title = "Hang on!";

      // Sign in errors
    } else if (error.code == "account-not-found") {
      print(error.message);
      message =
      "Please check your spelling and try again.";

      title = "Oh no!";
    } else if (error.code == "wrong-password") {
      message =
      "We don’t recognize your email address or password. Please check your spelling and try again.";

      title = "Oh no!";

      // General errors
    } else if (error.code == "invalid-email") {
      message =
      "The format of your email address doesn’t look right. Please check your spelling and try again.";

      title = "Oh no!";
    } else if (error.code == "weak-password") {
      message = "You need a password with at least 6 characters.";

      title = "Hang on!";
    }

    showDialogView(
      context,
      builder: (context) => AlertDialog(
        key: key,
        title: Text(title),
        content: Text(message),
        actions: <Widget>[
          TextButton(
            child: Text('OK'),
            onPressed: () {
              Navigator.of(context).pop();
            },
          )
        ],
      ),
    );
  }
}