import 'package:flutter/material.dart';
import 'package:flutter_helper/src/View/border_view.dart';
import 'package:flutter_helper/src/View/padded_view.dart';
import 'package:flutter_helper/src/enum/padding_enum.dart';

class ChildrenUtil {
  List<Widget> getAllPaddedChildren(List<Widget> children, {double padding = 12, bool isOutside = true, bool hasBorder = true, bool isVertical = true}) {
    for (var i = 0; i < children.length - 1; i++) {
      children[i] = PaddedView(
        child: children[i],
        paddingEnum: isVertical ? PaddingEnum.bottom : PaddingEnum.right,
        padding: padding,
      );
    }

    if (isOutside) {
      if (hasBorder) {
        for (var i = 0; i < children.length; i++) {
          children[i] = PaddedView(
            child: children[i],
            paddingEnum: isVertical ? PaddingEnum.horizontal : PaddingEnum.vertical,
          );
        }
      }

      if (children.isNotEmpty) {
        if (isVertical) {
          children.first = Padding(padding: EdgeInsets.only(top: padding), child: children.first,);

          children.last = Padding(padding: EdgeInsets.only(bottom: padding), child: children.last,);
        } else {
          children.first = Padding(padding: EdgeInsets.only(left: padding), child: children.first,);

          children.last = Padding(padding: EdgeInsets.only(right: padding), child: children.last,);
        }
      }
    }

    return children;
  }

  List<Widget> getDividedChildren(List<Widget> children, {Color? color, bool isOutside = false}) {
    for (var i = 0; i < children.length - 1; i++) {
      children[i] = BorderView(
        child: children[i],
        color: color,
      );
    }

    return [if (isOutside) Divider(height: 0.0, color: color,), ...children, if (isOutside) Divider(height: 0.0, color: color,)];
  }
}