import 'package:duration/duration.dart';
import 'package:intl/intl.dart';
import 'package:timeago/timeago.dart' as timeago;

class DateFormatUtil {
  String getTimeAgo(int milliseconds) {
    final DateTime creationDate = DateTime.fromMillisecondsSinceEpoch(milliseconds);

    final String format = timeago.format(creationDate);

    return format;
  }

  String formatToCupertinoPicker(DateTime dateTime) {
    return DateFormat('MMM d, yyyy').format(dateTime);
  }

  String formatToPicker(DateTime dateTime) {
    return DateFormat('EEEE, MMMM d').format(dateTime);
  }

  DateTime parseToPicker(String day) {
    return DateFormat('EEEE, MMM d').parse(day);
  }

  String formatToYMD(DateTime dateTime) {
    return DateFormat("yyyy-MM-dd").format(dateTime);
  }

  String formatToYM(DateTime dateTime) {
    return DateFormat("yyyy-MM").format(dateTime);
  }

  DateTime parseToYMD(String day) {
    return DateFormat("yyyy-MM-dd").parse(day);
  }

  String formatToMD(DateTime dateTime) {
    return DateFormat("MM-dd").format(dateTime);
  }

  String getWeek(DateTime dateTime) {
    final startOfWeek = dateTime.subtract(Duration(days: dateTime.weekday - 1));

    final endOfWeek = dateTime.add(Duration(days: DateTime.daysPerWeek - dateTime.weekday + 1));

    final start = DateFormatUtil().formatToYMD(startOfWeek);

    final end = DateFormatUtil().formatToYMD(endOfWeek);

    final week = start + "-to-" + end;

    return week;
  }

  DateTime parseToMD(String day) {
    return DateFormat("yyyy-MM").parse(day);
  }

  String formatPrettyDuration(Duration duration) {
    final watchtime = prettyDuration(
        duration,
        abbreviated: true,
        delimiter: " ",
        spacer: ""
    );

    return watchtime;
  }

  String formatDuration(Duration position) {
    final ms = position.inMilliseconds;

    int seconds = ms ~/ 1000;
    final int hours = seconds ~/ 3600;
    seconds = seconds % 3600;
    final minutes = seconds ~/ 60;
    seconds = seconds % 60;

    final hoursString = hours >= 10
        ? '$hours'
        : hours == 0
        ? '00'
        : '0$hours';

    final minutesString = minutes >= 10
        ? '$minutes'
        : minutes == 0
        ? '00'
        : '0$minutes';

    final secondsString = seconds >= 10
        ? '$seconds'
        : seconds == 0
        ? '00'
        : '0$seconds';

    final formattedTime =
        '${hoursString == '00' ? '' : '$hoursString:'}$minutesString:$secondsString';

    return formattedTime;
  }
}