import 'package:flutter/material.dart';
import 'package:flutter_helper/src/util/children_util.dart';
import 'package:image_picker/image_picker.dart';
import 'package:quiver/iterables.dart';
import 'circle_image_picker_view.dart';

class CircleImagesPickerView extends StatelessWidget {
  final List? images;
  final Function(ImageSource)? addImage;
  final Function(String)? removeImage;
  final bool? isLoading;
  final int itemCount;
  final List<String> texts;
  final int crossItemCount;

  CircleImagesPickerView({
    this.images,
    this.addImage,
    this.removeImage,
    this.isLoading,
    this.itemCount = 4,
    this.texts = const ["", "", "", ""],
    this.crossItemCount = 2
  });

  List<Widget?> _getPaddedChildren(List<Widget> children) {
    return ChildrenUtil().getAllPaddedChildren(children);
  }

  Widget _buildPictures(BuildContext context) {
    final List<Widget> children = [for (var i = 0; i < (itemCount); i++) CircleImagePickerView(i: i, addImage: addImage, removeImage: removeImage, isLoading: isLoading, images: images)];

    if (itemCount > 3) {
      final List partitionedChildren = partition(children, (crossItemCount)).toList();

      return Column(
        children: _getPaddedChildren([for (var i = 0; i < partitionedChildren.length; i++) Column(children: [
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text("${texts[i]}", style: TextStyle(fontSize: 18.0, fontWeight: FontWeight.w600),),
          ),
          Row(mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: partitionedChildren[i])
        ],)]) as List<Widget>,
      );
    } else {
      return Column(
        children: _getPaddedChildren([for (var i = 0; i < children.length; i++) Column(children: [
          Padding(
            padding: const EdgeInsets.all(8.0),
            child: Text("${texts[i]}", style: TextStyle(fontSize: 18.0, fontWeight: FontWeight.w600),),
          ),
          children[i]
        ],)]) as List<Widget>,
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return _buildPictures(context);
  }
}
