import 'package:flutter/material.dart';
import 'package:flutter_helper/src/util/date_format_util.dart';

import 'button_view.dart';

class DateView extends StatefulWidget {
  final Function? onSelected;
  final DateTime? dateTime;
  final String? text;
  final Color? color;
  final MainAxisAlignment? mainAxisAlignment;

  DateView({
    this.onSelected,
    this.dateTime,
    this.text = "Select date",
    this.color,
    this.mainAxisAlignment
  });

  @override
  _DateViewState createState() => _DateViewState();
}

class _DateViewState extends State<DateView> {
  Future<DateTime?> _showDatePicker(BuildContext context) async {
    final bool isNull = widget.dateTime == null || widget.dateTime == DateTime(3000);

    return showDatePicker(
        context: context,
        initialDate: isNull ? DateTime.now() : widget.dateTime!,
        firstDate: DateTime(2000),
        lastDate: DateTime(3000)
    );
  }

  @override
  Widget build(BuildContext context) {
    return ButtonView(
        mainAxisAlignment: widget.mainAxisAlignment,
        color: widget.color,
        iconData: Icons.calendar_today,
        text: widget.dateTime == null || widget.dateTime == DateTime(3000) ? widget.text : DateFormatUtil().formatToPicker(widget.dateTime!),
        onPressed: () async {
          final DateTime? dateTime = await _showDatePicker(context);

          if (dateTime != null) {
            widget.onSelected!(dateTime);
          }
        });
  }
}
