import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';

class DropDownView<T> extends StatefulWidget {
  final T? initialValue;
  final List<T> values;
  final Function onSelected;
  final String? label;

  DropDownView({
    this.initialValue,
    required this.values,
    required this.onSelected,
    this.label,
  });

  @override
  _DropDownViewState createState() => _DropDownViewState<T>();
}

class _DropDownViewState<T> extends State<DropDownView> {
  @override
  Widget build(BuildContext context) {
    final List<DropdownMenuItem<T>> items = [for (final value in widget.values) DropdownMenuItem<T>(
      value: value,
      child: Text(value.toString()),
    )];

    return SizedBox(
      height: kIsWeb ? 50 : 60,
      child: DropdownButtonFormField<T>(
          style: TextStyle(fontWeight: FontWeight.w600, color: Colors.black, fontSize: 16),
          decoration: InputDecoration(
              filled: true,
              fillColor: Theme.of(context).primaryColor.withOpacity(0.025),
              labelText: widget.label,
              labelStyle: TextStyle(color: Theme.of(context).primaryColor, fontWeight: FontWeight.w600),
              enabledBorder: OutlineInputBorder(
                  borderRadius: BorderRadius.circular(12),
                  borderSide: BorderSide(color: Theme.of(context).primaryColor.withOpacity(0.4))
              ),
          ),
          validator: (value) {
            return null;
          },
          isExpanded: true,
          value: widget.initialValue == "" ? null : widget.initialValue,
          iconEnabledColor: Colors.grey,
          icon: Icon(Icons.keyboard_arrow_down),
          iconSize: 24,
          elevation: 16,
          onChanged: (T? value) {
            widget.onSelected(value);
          },
          items: items
      ),
    );
  }
}
