import 'package:flutter/material.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';

class FutureProviderView<T> extends ConsumerWidget {
  final dynamic initialData;
  final ProviderListenable<AsyncValue> futureProvider;
  final Function(BuildContext, T) builder;
  final Widget? loader;

  FutureProviderView({
    this.initialData,
    required this.futureProvider,
    required this.builder,
    this.loader
  });

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final AsyncValue asyncValue = ref.watch(futureProvider);

    return asyncValue.when(data: (snapshot) {
      return builder(context, snapshot);
    }, error: (err, _) {
      return Center(child: Text("$err"));
    }, loading: () {
      return loader ?? Center(child: CircularProgressIndicator());
    });
  }
}