import 'package:flutter_helper/src/util/children_util.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:image_picker/image_picker.dart';
import 'package:flutter/material.dart';

class ImagePickerView extends ConsumerStatefulWidget {
  final Future<void> Function(XFile) onImageSelected;
  final String url;
  final String label;
  final double borderRadius;
  final double size;

  const ImagePickerView({
    required this.onImageSelected,
    required this.url,
    required this.label,
    this.borderRadius = 0,
    this.size = 200,
  });

  @override
  ConsumerState<ImagePickerView> createState() => _ThumbnailPickerViewState();
}

class _ThumbnailPickerViewState extends ConsumerState<ImagePickerView> {
  bool _isLoading = false;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: ChildrenUtil().getAllPaddedChildren([
         Text(widget.label),
         if (_isLoading) CircularProgressIndicator() else if (widget.url != "") ClipRRect(
           borderRadius: BorderRadius.circular(widget.borderRadius),
           child: Container(
              width: widget.size,
              height: widget.size,
              child: Image.network(widget.url, fit: BoxFit.cover,)),
         ),
        TextButton(onPressed: () async {
          final XFile? file = await ImagePicker().pickImage(source: ImageSource.gallery);

          if (file != null) {
            setState(() {
              _isLoading = true;
            });

            await widget.onImageSelected(file);

            setState(() {
              _isLoading = false;
            });
          }
        }, child: Text(widget.url == "" ? "Add image" : "Change image")),
      ], isOutside: false),
    );
  }
}
