import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class TextFieldView extends StatelessWidget {
  final String? label;
  final TextEditingController? controller;
  final Widget? prefixIcon;
  final Widget? suffixIcon;
  final TextCapitalization? textCapitalization;
  final bool? obscureText;
  final String? hintText;
  final TextInputType? keyboardType;
  final bool? autofocus;
  final bool? isMandatory;
  final Function? onSubmitted;
  final TextInputAction? textInputAction;
  final int? maxLines;
  final FormFieldValidator<String>? validator;
  final double? fontSize;
  final bool? readOnly;
  final Function? onTap;
  final InputBorder? border;
  final Function(String)? onChanged;
  final TextAlign? textAlign;
  final List<TextInputFormatter>? inputFormatters;
  final String? initialValue;

  const TextFieldView({
    this.initialValue,
    this.label,
    this.controller,
    this.prefixIcon,
    this.suffixIcon,
    this.textCapitalization,
    this.obscureText,
    this.hintText,
    this.keyboardType,
    this.autofocus,
    this.isMandatory,
    this.onSubmitted,
    this.textInputAction,
    this.maxLines,
    this.validator,
    this.fontSize,
    this.readOnly,
    this.onTap,
    this.onChanged,
    this.textAlign = TextAlign.start,
    this.border = const UnderlineInputBorder(),
    this.inputFormatters,
    Key? key
  }): super(key: key);
  
  @override
  Widget build(BuildContext context) {
    var _inputFormatters = <TextInputFormatter>[];

    if (keyboardType == TextInputType.number ||
        keyboardType == TextInputType.numberWithOptions(decimal: true)) {
      _inputFormatters = [FilteringTextInputFormatter.allow(RegExp('[0-9.,]+'))];
    } else if (keyboardType == TextInputType.numberWithOptions(decimal: true, signed: true) ||
        keyboardType == TextInputType.numberWithOptions(signed: true)) {
      _inputFormatters = [];
    }

    _inputFormatters.addAll(inputFormatters ?? []);

    return TextFormField(
      maxLines: (obscureText ?? false) ? 1 : maxLines,
      initialValue: initialValue,
      onChanged: onChanged,
      keyboardAppearance: Brightness.light,
      inputFormatters: _inputFormatters,
      onTap: onTap as void Function()?,
      readOnly: readOnly ?? false,
      textInputAction: textInputAction,
      onFieldSubmitted: onSubmitted as void Function(String)?,
      keyboardType: keyboardType,
      validator: validator,
      controller: controller,
      textAlign: textAlign ?? (label == null ? TextAlign.center : TextAlign.start),
      style: TextStyle(fontSize: fontSize ?? 16, fontWeight: FontWeight.w600),
      autofocus: autofocus ?? false,
      decoration: InputDecoration(
        contentPadding: label == null ? EdgeInsets.all(12.0) : null,
        filled: true,
        fillColor: Theme.of(context).primaryColor.withOpacity(0.025),
        enabledBorder: OutlineInputBorder(
            borderRadius: BorderRadius.circular(12),
            borderSide: BorderSide(color: Theme.of(context).primaryColor.withOpacity(0.4))
        ),
        border: OutlineInputBorder(
            borderRadius: BorderRadius.circular(12),
        ),
        prefixIcon: prefixIcon,
        suffixIcon: suffixIcon,
        hintText: hintText,
        labelText: label,
        alignLabelWithHint: true,
        labelStyle: TextStyle(color: Theme.of(context).primaryColor, fontWeight: FontWeight.w600),
      ),
      textCapitalization: textCapitalization ?? TextCapitalization.none,
      obscureText: obscureText ?? false,
    );
  }
}