import 'package:chewie/chewie.dart';
import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'package:flutter_helper/src/view/future_view.dart';
import 'package:video_player/video_player.dart';

class UrlVideoPlayerView extends StatefulWidget {
  final Function(VideoPlayerValue)? onVideoUpdate;
  final Duration position;
  final String url;

  const UrlVideoPlayerView({
    this.onVideoUpdate,
    this.position = const Duration(),
    required this.url
  });

  @override
  State<UrlVideoPlayerView> createState() => _UrlVideoPlayerViewState();
}

class _UrlVideoPlayerViewState extends State<UrlVideoPlayerView> {
  late ChewieController _chewieController;

  VideoPlayerController? _videoPlayerController;

  late Future _future;

  @override
  void initState() {
    // TODO: implement initState
    super.initState();

    if (widget.url != "") {
      _future = _init();
    }
  }

  _init() async {
    _videoPlayerController = VideoPlayerController.network(widget.url);

    await _videoPlayerController!.initialize();

    _chewieController = ChewieController(
      videoPlayerController: _videoPlayerController!,
      aspectRatio: _videoPlayerController!.value.aspectRatio,
    );

    _chewieController.seekTo(widget.position);

    _videoPlayerController!.addListener(() {
      if (widget.onVideoUpdate != null) {
        widget.onVideoUpdate!(_videoPlayerController!.value);
      }
    });
  }

  @override
  void dispose() {
    // TODO: implement dispose
    super.dispose();

    if (_videoPlayerController != null) {
      _videoPlayerController!.dispose();
    }
  }

  @override
  Widget build(BuildContext context) {
    if (widget.url != "") {
      return FutureView<void>(
        future: _future,
        builder: (context, snapshot) {
          return AspectRatio(
              aspectRatio: _chewieController.aspectRatio!,
              child: Chewie(controller: _chewieController));
        }
      );
    } else {
      return Center(child: Padding(
        padding: const EdgeInsets.all(8.0),
        child: Text("No url", style: TextStyle(color: Colors.blue),),
      ));
    }
  }
}