import 'package:flutter/material.dart';
import 'package:flutter_helper/flutter_helper.dart';
import 'outlined_text_field_view.dart';

class ValueFieldView<T> extends StatelessWidget {
  final String label;
  final Function onChanged;
  final String initialValue;

  ValueFieldView({
    required this.label,
    required this.onChanged,
    required this.initialValue
  });

  @override
  Widget build(BuildContext context) {
    TextInputType? type;

    switch (T) {
      case double:
        type = TextInputType.numberWithOptions(decimal: true);
        break;
      case int:
        type = TextInputType.number;
        break;
      case String:
        type = null;
        break;
    }

    return OutlinedTextFieldView(
      initialValue: initialValue,
      onChanged: (String value) {
        dynamic text;

        switch (T) {
          case double:
            if (value == "") {
              text = 0.0;
            } else {
              text = double.tryParse(value);
            }

            break;
          case int:
            if (value == "") {
              text = 0;
            } else {
              text = int.tryParse(value);
            }

            break;
          case String:
            text = value;

            break;
        }

        onChanged(text);
      },
      label: label,
      textInputAction: TextInputAction.done,
      keyboardType: type,
    );
  }
}