import 'package:flutter/material.dart';
import 'package:flutter_helper/src/util/children_util.dart';
import 'package:flutter_helper/src/view/url_video_player_view.dart';
import 'package:flutter_riverpod/flutter_riverpod.dart';
import 'package:image_picker/image_picker.dart';
import 'package:video_player/video_player.dart';

class VideoPickerView extends ConsumerStatefulWidget {
  final Future<void> Function(XFile) onVideoPicked;
  final Function(VideoPlayerValue)? onVideoUpdate;
  final String url;
  final String label;

  const VideoPickerView(
      {
        required this.onVideoPicked,
      this.onVideoUpdate,
      required this.url,
      required this.label});

  @override
  _VideoPickerViewState createState() => _VideoPickerViewState();
}

class _VideoPickerViewState extends ConsumerState<VideoPickerView> {
  bool _isLoading = false;

  @override
  Widget build(BuildContext context) {
    return Column(
      children: ChildrenUtil().getAllPaddedChildren([
        Text(widget.label),
        if (_isLoading)
          CircularProgressIndicator()
        else if (widget.url != "")
          SizedBox(
              width: 200,
              height: 200,
              child: UrlVideoPlayerView(
                url: widget.url,
                onVideoUpdate: widget.onVideoUpdate,
              )),
        TextButton(
            onPressed: () async {
              final XFile? file =
                  await ImagePicker().pickVideo(source: ImageSource.gallery);

              if (file != null) {
                setState(() {
                  _isLoading = true;
                });

                await widget.onVideoPicked(file);

                setState(() {
                  _isLoading = false;
                });
              }
            },
            child: Text(widget.url == "" ? "Add video" : "Change video")),
      ], isOutside: false),
    );
  }
}
